@@ -21,33 +21,33 @@ def test_get(logged_in_context):
 def test_get_deployments(logged_in_context):
     """Test the CLI."""
     runner = CliRunner()
-    result = runner.invoke(get.get_deployment_by_repo_id)
+    result = runner.invoke(get.get_deployment_by_id)
     assert result.exit_code == 0
-    assert "7f83d907-0809-4ecb-91de-5a357b543da3" in result.output
-    assert "a2a94e2b-d8af-4e4d-a72b-512edf920015" in result.output
-    assert "78cf08ee-10f0-4476-ad5f-fedd919f7f75" in result.output
+    assert "9b503d88-5f49-46d4-806a-aed3134ba973" in result.output
+    assert "437445ed-edc1-4cb9-ad4f-4ef2af086eae" in result.output
+    assert "f91b6781-405b-43df-b825-956627019c0b" in result.output
     as_io = StringIO(result.output)
     lines = as_io.readlines()
-    assert len(lines) >= 6
+    assert len(lines) >= 4
 
 
 def test_get_deployments_with_options(logged_in_context):
     runner = CliRunner()
     result_with_id = runner.invoke(
-        get.get_deployment_by_repo_id, "99ffb2dc-b06d-4262-b2e0-34cd40a0c56d"
+        get.get_deployment_by_id, "9b503d88-5f49-46d4-806a-aed3134ba973"
     )
-    assert "refs/heads/master @ d6aa3de" in result_with_id.output
+    assert "refs/heads/main @ 3e2dd56" in result_with_id.output
     as_io = StringIO(result_with_id.output)
     lines = as_io.readlines()
-    assert len(lines) == 3
+    assert len(lines) == 2
 
 
 def test_json_resources(logged_in_context):
     runner = CliRunner()
     for command in [
-        get.get_deployment_by_repo_id,
-        get.get_repositories,
-        get.get_endpoint_by_deployment_id,
+        get.get_deployment_by_id,
+        get.get_repository_by_id,
+        get.get_endpoint_by_id,
     ]:
         result = runner.invoke(command, ["-O", "json", "-a"])
         assert result.exit_code == 0
@@ -56,15 +56,15 @@ def test_json_resources(logged_in_context):
         loaded = json.loads(lines)
         assert isinstance(loaded, list)
         for item in loaded:
-            assert "id" in item.keys() or "deployment_id" in item.keys()
+            assert "id" in item.keys()
 
 
 def test_yaml_resources(logged_in_context):
     runner = CliRunner()
     for command in [
-        get.get_deployment_by_repo_id,
-        get.get_repositories,
-        get.get_endpoint_by_deployment_id,
+        get.get_deployment_by_id,
+        get.get_repository_by_id,
+        get.get_endpoint_by_id,
     ]:
         result = runner.invoke(command, ["-O", "yaml", "-a"])
         assert result.exit_code == 0
@@ -72,4 +72,4 @@ def test_yaml_resources(logged_in_context):
         lines = as_io.read()
         loaded = [l for l in yaml.safe_load_all(lines)]
         assert len(loaded) >= 3
-        assert all([("id" in k.keys() or "deployment_id" in k.keys()) for k in loaded])
+        assert all(["id" in k.keys() for k in loaded])
