@@ -13,7 +13,7 @@ def test_instantiate_taktile_client():
     AuthConfigManager.set_api_key(key)
     client = TaktileClient(api_url=settings.DEPLOYMENT_API_URL)
     with pytest.raises(TaktileSdkError):
-        r = client.get_endpoint_by_name("admin/df.asfm", "", "")
+        r = client.get_endpoints_for_repository("admin/df.asfm")
     assert "X-Api-Key" in client.default_headers
     assert client.default_headers["X-Api-Key"] == key
     assert (
