@@ -4,6 +4,14 @@ import pytest
 
 from tktl.login import login, logout
 
+pytest_plugins = [
+    "tests.cli",
+    "tests.sdk",
+    "tests.clients",
+    "tests.managers",
+    "tests.commands",
+]
+
 
 @pytest.fixture
 def user_key():
@@ -13,9 +21,9 @@ def user_key():
 @pytest.fixture
 def test_user_deployed_repos():
     return (
+        ("tktl-admin/sample-project", "master", "repayment"),
         ("tktl-admin/other-project", "testbranch", "repayment"),
         ("tktl-admin/other-project", "master", "repayment"),
-        ("tktl-admin/sample-project", "master", "repayment"),
         ("tktl-admin/integ-testing", "master", "repayment"),
         ("tktl-admin/grpc-test", "main", "repayment"),
     )
