@@ -7,6 +7,11 @@ from pydantic import BaseModel
 
 from tktl import Tktl
 from tktl.core.exceptions.exceptions import ValidationException
+from tktl.registration.validation import (
+    get_input_and_output_for_profiling,
+    input_pandas_representation,
+    output_pandas_representation,
+)
 
 
 @pytest.mark.parametrize(
@@ -73,7 +78,7 @@ def test_custom_kind():
         assert isinstance(endpoint.func, Callable)
         assert endpoint.func(["foo"]) == ["foo"]
 
-    x = pd.DataFrame([{'a': 1, 'b': 2}, {'a': 1, 'b': 2}, {'a': 1, 'b': 2}])
+    x = pd.DataFrame([{"a": 1, "b": 2}, {"a": 1, "b": 2}, {"a": 1, "b": 2}])
     y = pd.Series([1, 2, 3])
 
     @tktl.endpoint(kind="custom", X=x, y=y)
@@ -81,8 +86,8 @@ def test_custom_kind():
         return x
 
     schema = tktl.endpoints[1].input_schema.pydantic.schema()
-    assert schema['title'] == "DataFrame__predict_typed__input"
-    assert schema['example'] == [{'a': 1, 'b': 2}]
+    assert schema["title"] == "DataFrame__predict_typed__input"
+    assert schema["example"] == [{"a": 1, "b": 2}]
 
 
 def test_func_shape():
@@ -126,6 +131,7 @@ def test_validate_func():
     y = [4, 5, 5]
 
     with pytest.raises(ValidationException):
+
         @tktl.endpoint(X=X, y=y, kind="binary")
         def predict_binary(X):
             return [-2, 0, 1.5]  # must be in [0, 1]
@@ -154,7 +160,13 @@ def test_missing():
         return [0] * len(X)
 
     with pytest.warns(UserWarning):
-        tktl.endpoints[0].get_input_and_output_for_profiling()
+        x_raw = input_pandas_representation(
+            value=tktl.endpoints[0].input_schema.value, reset_index=False
+        )
+        y_raw = output_pandas_representation(
+            value=tktl.endpoints[0].output_schema.value, reset_index=False
+        )
+        get_input_and_output_for_profiling(x=x_raw, y=y_raw)
 
 
 def test_large():
@@ -163,12 +175,11 @@ def test_large():
     X = pd.DataFrame({"a": np.random.uniform(size=n)})
     y = pd.Series(np.random.uniform(size=n))
 
-    @tktl.endpoint(X=X, y=y, kind="regression")
-    def predict(X):
-        return [0] * len(X)
-
     with pytest.warns(UserWarning):
-        tktl.endpoints[0].get_input_and_output_for_profiling()
+
+        @tktl.endpoint(X=X, y=y, kind="regression")
+        def predict(X):
+            return [0] * len(X)
 
 
 def test_custom():
