@@ -5,18 +5,10 @@ import click
 import yaml
 from pydantic import UUID4, BaseModel
 
-from tktl.cli.common import (
-    LOG,
-    ClickGroup,
-    filter_deploy_shared_options,
-    filter_repo_shared_options,
-    get_cmd_shared_options,
-    to_uuid,
-)
+from tktl.cli.common import LOG, ClickGroup, get_cmd_shared_options, to_uuid
 from tktl.commands import deployments as deployments_commands
 from tktl.core.config import settings
 from tktl.core.schemas.utils import get_table_from_list_of_schemas
-from tktl.core.t import EndpointKinds
 from tktl.login import validate_decorator
 
 
@@ -25,104 +17,74 @@ def get():
     pass
 
 
-@get.command("repositories", help="Get repository resources")
-@get_cmd_shared_options
-@filter_repo_shared_options
-@validate_decorator
-def get_repositories(
-    repo: str, owner: str, all_resources: bool, output: str, full: bool,
-):
-    command = deployments_commands.GetRepositories()
-    result = command.execute(
-        repository_name=repo, repository_owner=owner, return_all=all_resources,
-    )
-    keys = None
-    if not full:
-        keys = ["ID", "NAME", "DEPLOYMENTS"]
-        result = list(set(result))
-    return produce_output(resources=result, keys=keys, maxwidth=200, output_kind=output)
-
-
 @get.command("deployments", help="Get deployment resources")
-@click.argument("repository_id", required=False, callback=to_uuid)
+@click.argument("deployment_id", required=False, callback=to_uuid)
+@click.option("-c", "--commit", help="SHA commit")
+@click.option("-b", "--branch", help="Branch Name")
+@click.option("-s", "--status", help="Status in which deployment is")
 @get_cmd_shared_options
-@filter_deploy_shared_options
-@filter_repo_shared_options
 @validate_decorator
-def get_deployment_by_repo_id(
-    repository_id: UUID4,
-    repo: str,
-    owner: str,
+def get_deployment_by_id(
+    deployment_id: UUID4,
     commit: str,
     branch: str,
     status: str,
+    full: bool,
     all_resources: bool,
     output: str,
-    full: bool,
 ):
     command = deployments_commands.GetDeployments()
-    if output == "stdout" and not repository_id:
-        LOG.warning(
-            "Fetching multiple deployments, this can take a few seconds. "
-            "Pass a repository_id or branch/commit if you only want the deployments for a specific repository"
-        )
-
     result = command.execute(
-        repository_id=repository_id,
-        repository_name=repo,
-        repository_owner=owner,
+        deployment_id=deployment_id,
         git_hash=commit,
         branch_name=branch,
         status_name=status,
         return_all=all_resources,
     )
-    keys = ["ID", "BRANCH @ COMMIT", "STATUS", "ENDPOINTS"] if not full else None
+    keys = ["id", "Branch @ Commit", "Status"] if not full else None
     return produce_output(resources=result, keys=keys, maxwidth=350, output_kind=output)
 
 
-@get.command("endpoints", help="Get endpoint resources")
-@click.argument("deployment_id", required=False, callback=to_uuid)
-@click.option("-e", "--endpoint", help="Endpoint name")
-@click.option(
-    "-k",
-    "--endpoint-kind",
-    help="Endpoint kind",
-    type=click.Choice(EndpointKinds.list()),
-)
+@get.command("repositories", help="Get repository resources")
+@click.argument("repository_id", required=False, callback=to_uuid)
+@click.option("-r", "--repo-name", help="Repository name")
+@click.option("-o", "--owner", help="Owner of the repository")
 @get_cmd_shared_options
-@filter_deploy_shared_options
-@filter_repo_shared_options
 @validate_decorator
-def get_endpoint_by_deployment_id(
-    deployment_id: UUID4,
-    repo: str,
+def get_repository_by_id(
+    repository_id: UUID4,
+    repo_name: str,
     owner: str,
-    commit: str,
-    branch: str,
-    status: str,
-    endpoint_kind,
-    endpoint: str,
+    full: bool,
+    all_resources: bool,
+    output: str,
+):
+    command = deployments_commands.GetRepositories()
+    result = command.execute(
+        repository_id=repository_id,
+        repository_name=repo_name,
+        repository_owner=owner,
+        return_all=all_resources,
+    )
+    keys = ["Name"] if not full else None
+    return produce_output(resources=result, keys=keys, maxwidth=200, output_kind=output)
+
+
+@get.command("endpoints", help="Get endpoint resources")
+@click.argument("endpoint_id", required=False, callback=to_uuid)
+@click.option("-e", "--endpoint-name", help="Endpoint name")
+@get_cmd_shared_options
+@validate_decorator
+def get_endpoint_by_id(
+    endpoint_id: UUID4,
+    endpoint_name: str,
     all_resources: bool,
     output: str,
     full: bool = True,
 ):
     command = deployments_commands.GetEndpoints()
-    if output == "stdout" and not deployment_id:
-        LOG.warning(
-            "Fetching multiple endpoints, this can take a few seconds. "
-            "Pass a deployment_id if you only want the endpoints for a specific deployment"
-        )
-
     result = command.execute(
-        deployment_id=deployment_id,
-        endpoint_name=endpoint,
-        endpoint_kind=endpoint_kind,
-        repository_name=repo,
-        repository_owner=owner,
-        git_hash=commit,
-        branch_name=branch,
-        status_name=status,
-        return_all=all_resources,
+        endpoint_id=endpoint_id, endpoint_name=endpoint_name, return_all=all_resources
     )
     return produce_output(resources=result, output_kind=output, keys=None, maxwidth=130)
 
