@@ -1,9 +1,6 @@
 import click
 
 from tktl.commands import login as login_commands
-from tktl.core.loggers import CliLogger
-
-logger = CliLogger()
 
 
 @click.command("login", help="Log in & store api key")
