@@ -5,11 +5,7 @@ from tktl.commands.run import run_container
 
 @click.command()
 @click.option(
-    "--path",
-    "-p",
-    help="Directory where the deployment lives",
-    required=False,
-    default=".",
+    "--path", help="Directory where the deployment lives", required=False, default="."
 )
 @click.option("--nocache", help="Enable or disable using cache of images", is_flag=True)
 @click.option("--background", help="Run the image in the background", is_flag=True)
