@@ -95,7 +95,7 @@ def validate_integration(path: str, nocache: bool):
         dm, image = build_image(path, nocache=nocache)
         LOG.log("Waiting for service to start...")
         rest_response, grpc_response, container = dm.run_and_check_health(
-            image, kill_on_success=True, auth_enabled=False
+            image, kill_on_success=True
         )
         if _validate_container_response(
             rest_response=rest_response,
