@@ -18,8 +18,7 @@ class Client(object):
         self,
         api_key: str,
         repository_name: str,
-        branch_name: str,
-        endpoint_name: str,
+        branch_name: str = None,
         local: bool = False,
         logger: Logger = LOG,
         verbosity: int = 0,
@@ -32,7 +31,6 @@ class Client(object):
         )
         self.repository_name = repository_name
         self.branch_name = branch_name
-        self.endpoint_name = endpoint_name
         self.logger = logger
         self._location = None
         self._endpoint = None
@@ -53,6 +51,10 @@ class Client(object):
     def location(self):
         return self._location
 
+    @property
+    def endpoint(self):
+        return self._endpoint
+
     @client.setter
     def client(self, client: Union[API, FlightClient]):
         self._client = client
@@ -61,6 +63,10 @@ class Client(object):
     def location(self, value):
         self._location = value
 
+    @endpoint.setter
+    def endpoint(self, value):
+        self._endpoint = value
+
     def predict(self, *args, **kwargs):
         raise NotImplementedError
 
@@ -68,26 +74,29 @@ class Client(object):
         self.location = location
         self.client = client
 
-    def get_deployment_location(self):
-        deployment = self.taktile_client.get_deployment_by_branch_name(
-            repository_name=self.repository_name, branch_name=self.branch_name,
-        )
-        return self.format_url(deployment.public_docs_url)
-
-    def get_endpoint_and_location(self):
+    def get_endpoint_and_location(self, endpoint_name: str):
+        self.endpoint = endpoint_name
         if self.local:
             location = self.local_endpoint
         else:
             location = self._get_endpoint_location()
+            if not location:
+                return
+            location = self.format_url(location.public_docs_url)
         return location
 
     def _get_endpoint_location(self):
-        deployment, endpoint = self.taktile_client.get_endpoint_by_name(
-            repository_name=self.repository_name,
-            endpoint_name=self.endpoint_name,
+        endpoint_mapping = self.taktile_client.get_endpoints_for_repository(
+            repository=self.repository_name
+        )
+        filtered_by_user = get_deployment_from_endpoint_and_branch(
+            endpoint_mapping=endpoint_mapping,
+            endpoint_name=self.endpoint,
             branch_name=self.branch_name,
         )
-        return self.format_url(deployment.public_docs_url)
+        if not filtered_by_user:
+            return
+        return filtered_by_user
 
     def list_deployments(self):
         raise NotImplementedError
