@@ -45,24 +45,19 @@ class ArrowFlightClient(Client):
         self,
         api_key: str,
         repository_name: str,
-        branch_name: str,
-        endpoint_name: str,
+        branch_name: str = None,
         local: bool = False,
         logger: Logger = LOG,
         verbosity: int = 0,
-        health_check: bool = False,
     ):
         super().__init__(
             api_key=api_key,
             repository_name=repository_name,
             branch_name=branch_name,
-            endpoint_name=endpoint_name,
             local=local,
             logger=logger,
             verbosity=verbosity,
         )
-        if not health_check:
-            self.authenticate()
 
     @staticmethod
     def format_url(url: str) -> str:
@@ -78,16 +73,10 @@ class ArrowFlightClient(Client):
     def list_commands(self):
         return self.client.list_actions()
 
-    def authenticate(self, health_check: bool = False):
-        if health_check:
-            location = self.get_deployment_location()
-        else:
-            try:
-                location = self.get_endpoint_and_location()
-            except APIClientException as e:
-                self.logger.error(f"Unable to authenticate: {e.detail}")
-                return
-
+    def authenticate(self, endpoint_name: str):
+        location = self.get_endpoint_and_location(endpoint_name)
+        if not location:
+            return
         certs = load_certs()
         client = FlightClient(tls_root_certs=certs, location=location)
         self.logger.trace(f"Performing authentication request against {location}")
@@ -99,7 +88,7 @@ class ArrowFlightClient(Client):
     def predict(self, inputs):
         table = serialize_arrow(inputs)
         batch_size, batch_memory = get_chunk_size(table)
-        descriptor = self.get_flight_info(command_name=str.encode(self.endpoint_name))
+        descriptor = self.get_flight_info(command_name=str.encode(self.endpoint))
         writer, reader = self.client.do_exchange(descriptor.descriptor)
         self.logger.trace(
             f"Initiating prediction request with batches of {batch_size} records of "
@@ -120,18 +109,18 @@ class ArrowFlightClient(Client):
         return deserialize_arrow(Table.from_batches(chunks, schema))
 
     def get_sample_data(self):
-        if not self.endpoint_name:
+        if not self.endpoint:
             raise AuthenticationError(
                 "Please authenticate against a specific endpoint first"
             )
         x_ticket, y_ticket = (
-            str.encode(f"{self.endpoint_name}__X"),
-            str.encode(f"{self.endpoint_name}__y"),
+            str.encode(f"{self.endpoint}__X"),
+            str.encode(f"{self.endpoint}__y"),
         )
         return self._get_data(ticket=x_ticket), self._get_data(ticket=y_ticket)
 
     def _get_data(self, ticket):
-        if not self.endpoint_name:
+        if not self.endpoint:
             raise AuthenticationError(
                 "Please authenticate against a specific endpoint first"
             )
@@ -140,11 +129,11 @@ class ArrowFlightClient(Client):
         return deserialize_arrow(reader.read_all())
 
     def get_schema(self):
-        if not self.endpoint_name:
+        if not self.endpoint:
             raise AuthenticationError(
                 "Please authenticate against a specific endpoint first"
             )
-        info = self.get_flight_info(str.encode(self.endpoint_name))
+        info = self.get_flight_info(str.encode(self.endpoint))
         return info.schema
 
     def get_flight_info(self, command_name: bytes) -> FlightInfo:
