@@ -1,13 +1,13 @@
 import copy
 from json import JSONDecodeError
-from typing import List, Type
+from typing import List, Optional, Type
 
 import requests
 from pydantic import BaseModel, parse_obj_as
 
-from tktl.core import loggers as sdk_logger
 from tktl.core import utils
 from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.loggers import LOG, Logger
 from tktl.core.managers.auth import AuthConfigManager
 
 
@@ -16,14 +16,13 @@ class API(object):
         "Accept": "application/json",
     }
 
-    def __init__(self, api_url, headers=None, logger=sdk_logger.MuteLogger()):
+    def __init__(self, api_url, headers=None, logger: Logger = LOG):
         """
 
         Parameters
         ----------
         api_url
         headers
-        logger
         """
 
         self.api_url = api_url
@@ -34,8 +33,8 @@ class API(object):
     @property
     def default_headers(self):
         api_key = AuthConfigManager.get_api_key()
-        self.DEFAULT_HEADERS.update({"X-Api-Key": api_key})
-        return self.DEFAULT_HEADERS
+        self.headers.update({"X-Api-Key": api_key})
+        return self.headers
 
     def get_path(self, url=None):
         if not url:
@@ -47,7 +46,7 @@ class API(object):
         path = self.get_path(url)
         headers = copy.deepcopy(self.default_headers)
 
-        self.logger.debug(
+        self.logger.trace(
             "POST request sent to: {} \n\theaders: {}\n\tjson: {}\n\tparams: {}\n\tfiles: {}\n\tdata: {}".format(
                 path, headers, json, params, files, data
             )
@@ -55,13 +54,13 @@ class API(object):
         response = requests.post(
             path, json=json, params=params, headers=headers, files=files, data=data
         )
-        self.logger.debug("Response status code: {}".format(response.status_code))
-        self.logger.debug("Response content: {}".format(response.content))
+        self.logger.trace("Response status code: {}".format(response.status_code))
+        self.logger.trace("Response content: {}".format(response.content))
         return response
 
     def put(self, url=None, json=None, params=None, data=None):
         path = self.get_path(url)
-        self.logger.debug(
+        self.logger.trace(
             "PUT request sent to: {} \n\theaders: {}\n\tjson: {}\n\tparams: {}".format(
                 path, self.headers, json, params
             )
@@ -69,13 +68,13 @@ class API(object):
         response = requests.put(
             path, json=json, params=params, headers=self.default_headers, data=data
         )
-        self.logger.debug("Response status code: {}".format(response.status_code))
-        self.logger.debug("Response content: {}".format(response.content))
+        self.logger.trace("Response status code: {}".format(response.status_code))
+        self.logger.trace("Response content: {}".format(response.content))
         return response
 
     def patch(self, url=None, json=None, params=None, data=None):
         path = self.get_path(url)
-        self.logger.debug(
+        self.logger.trace(
             "PATCH request sent to: {} \n\theaders: {}\n\tjson: {}\n\tparams: {}".format(
                 path, self.headers, json, params
             )
@@ -83,14 +82,13 @@ class API(object):
         response = requests.patch(
             path, json=json, params=params, headers=self.default_headers, data=data
         )
-        self.logger.debug("Response status code: {}".format(response.status_code))
-        self.logger.debug("Response content: {}".format(response.content))
+        self.logger.trace("Response status code: {}".format(response.status_code))
+        self.logger.trace("Response content: {}".format(response.content))
         return response
 
     def get(self, url=None, json=None, params=None):
         path = self.get_path(url)
-
-        self.logger.debug(
+        self.logger.trace(
             "GET request sent to: {} \n\theaders: {}\n\tjson: {}\n\tparams: {}".format(
                 path, self.headers, json, params
             )
@@ -98,27 +96,30 @@ class API(object):
         response = requests.get(
             path, params=params, headers=self.default_headers, json=json
         )
-        self.logger.debug("Response status code: {}".format(response.status_code))
-        self.logger.debug("Response content: {}".format(response.content))
+        self.logger.trace("Response status code: {}".format(response.status_code))
+        self.logger.trace("Response content: {}".format(response.content))
         return response
 
     def delete(self, url=None, json=None, params=None):
         path = self.get_path(url)
         response = requests.delete(path, params=params, headers=self.headers, json=json)
-        self.logger.debug(
+        self.logger.trace(
             "DELETE request sent to: {} \n\theaders: {}\n\tjson: {}\n\tparams: {}".format(
                 response.url, self.headers, json, params
             )
         )
-        self.logger.debug("Response status code: {}".format(response.status_code))
-        self.logger.debug("Response content: {}".format(response.content))
+        self.logger.trace("Response status code: {}".format(response.status_code))
+        self.logger.trace("Response content: {}".format(response.content))
         return response
 
 
-def interpret_response(response: requests.Response, model: Type[BaseModel]):
+def interpret_response(
+    response: requests.Response, model: Optional[Type[BaseModel]], ping: bool = False
+):
     """
     Parameters
     ----------
+    ping
     response
 
     model
@@ -141,6 +142,8 @@ def interpret_response(response: requests.Response, model: Type[BaseModel]):
                 status_code=e.response.status_code,
                 detail=f"Something went wrong: {repr(response.content)}",
             )
+    if ping:
+        return response
     if model:
         json = response.json()
         if isinstance(json, list):
