@@ -6,6 +6,7 @@ from openapi_schema_pydantic import OpenAPI
 from tktl.core.clients import Client
 from tktl.core.clients.http_client import API, interpret_response
 from tktl.core.config import settings
+from tktl.core.exceptions import AuthenticationError
 from tktl.core.loggers import LOG, Logger
 from tktl.core.schemas.repository import _format_http_url
 from tktl.core.t import ServiceT
@@ -21,28 +22,23 @@ class RestClient(Client):
         self,
         api_key: str,
         repository_name: str,
-        branch_name: str,
-        endpoint_name: str,
+        branch_name: str = None,
         local: bool = False,
         logger: Logger = LOG,
         verbosity: int = 0,
-        health_check: bool = False,
     ):
         super().__init__(
             api_key=api_key,
             repository_name=repository_name,
             branch_name=branch_name,
-            endpoint_name=endpoint_name,
             local=local,
             logger=logger,
             verbosity=verbosity,
         )
-        if not health_check:
-            self.authenticate()
 
     def predict(self, inputs):
         response = self.client.post(
-            url=f"model/{self.endpoint_name}", data=json.dumps(inputs)
+            url=f"model/{self.endpoint}", data=json.dumps(inputs)
         )
         return response.json()
 
@@ -50,11 +46,10 @@ class RestClient(Client):
     def format_url(url: str):
         return _format_http_url(url, docs=False)
 
-    def authenticate(self, health_check: bool = False):
-        if health_check:
-            location = self.get_deployment_location()
-        else:
-            location = self.get_endpoint_and_location()
+    def authenticate(self, endpoint_name: str):
+        location = self.get_endpoint_and_location(endpoint_name)
+        if not location:
+            return
         client = API(api_url=location)
         self.set_client_and_location(location=location, client=client)
 
@@ -66,10 +61,14 @@ class RestClient(Client):
         pass
 
     def get_sample_data(self):
+        if not self.client or not self.endpoint:
+            raise AuthenticationError(
+                "Please authenticate against a specific endpoint first"
+            )
         schema = self.client.get(url="openapi.json")
         openapi = OpenAPI.parse_obj(schema.json())
         request_reference, response_reference = get_endpoint_model_reference(
-            openapi, endpoint=self.endpoint_name
+            openapi, endpoint=self.endpoint
         )
         sample_input = openapi.components.schemas[request_reference].example
         if not sample_input:
