@@ -1,13 +1,15 @@
 import os
 from typing import Any, Callable, Dict, List, Optional, Union
 
+from pydantic import UUID4
+
 from tktl.core.exceptions import TaktileSdkError
 from tktl.core.loggers import LOG
 from tktl.core.schemas.repository import Endpoint, Repository, RepositoryDeployment
 from tktl.core.t import Resources
 
 default_comp = lambda x, y: x == y
-branch_comp = lambda x, y: (x == y or os.path.basename(y) == x)
+branch_comp = lambda x, y: ((x == y) or (os.path.basename(x) == y))
 
 
 def filter_prop(
@@ -20,10 +22,19 @@ def filter_prop(
 
 def filter_deployments(
     deployments: List[RepositoryDeployment],
+    deployment_id: UUID4,
     git_hash: str = None,
     branch_name: str = None,
     status_name: str = None,
 ) -> List[RepositoryDeployment]:
+    if deployment_id:
+        deployments = [d for d in deployments if d.id == deployment_id]
+
+        if deployments:
+            return deployments
+        else:
+            LOG.warning("No deployments with matching id found")
+
     for n, v in zip(
         ["commit_hash", "git_ref", "status"], [git_hash, branch_name, status_name]
     ):
@@ -43,9 +54,17 @@ def filter_deployments(
 
 def filter_repositories(
     repositories: List[Repository],
+    repository_id: UUID4,
     repository_name: str = None,
     repository_owner: str = None,
 ) -> List[Repository]:
+    if repository_id:
+        repositories = [r for r in repositories if r.id == repository_id]
+        if repositories:
+            return repositories
+        else:
+            LOG.warning("No repositories with matching id found")
+
     for n, v in zip(
         ["repository_name", "repository_owner"], [repository_name, repository_owner]
     ):
@@ -54,10 +73,16 @@ def filter_repositories(
 
 
 def filter_endpoints(
-    endpoints: List[Endpoint], endpoint_name: str = None, endpoint_kind: str = None
+    endpoints: List[Endpoint], endpoint_id: UUID4, endpoint_name: str = None
 ) -> List[Endpoint]:
+    if endpoint_id:
+        endpoints = [r for r in endpoints if r.id == endpoint_id]
+        if endpoints:
+            return endpoints
+        else:
+            LOG.warning("No endpoints with matching id found")
 
-    for n, v in zip(["name", "kind"], [endpoint_name, endpoint_kind]):
+    for n, v in zip(["name"], [endpoint_name]):
         endpoints = filter_prop(endpoints, prop_name=n, value=v)
     return endpoints
 
