@@ -9,7 +9,8 @@ class Settings(BaseSettings):
     USERS_OPEN_REGISTRATION: bool = False
     IN_TESTING = False
 
-    DEBUG: bool = False
+    VERBOSE: bool = None
+    DEBUG: bool = None
     WEB_URL: str = "https://app.taktile.com"
     TAKTILE_API_URL: str = "https://taktile-api.taktile.com"
     DEPLOYMENT_API_URL: str = "https://deployment-api.taktile.com"
@@ -26,6 +27,10 @@ class Settings(BaseSettings):
         "help_options_color": "green",
     }
 
+    LOCAL_ARROW_ENDPOINT: str = "grpc+tcp://127.0.0.1:5005"
+    LOCAL_REST_ENDPOINT: str = "http://127.0.0.1:8080"
+    ARROW_BATCH_MB: int = 50
+
     class Config:
         case_sensitive = True
 
