@@ -3,20 +3,19 @@ import pkgutil
 import sys
 from typing import Optional
 
-from tktl.core.loggers import CliLogger
+from tktl import __version__
+from tktl.core.loggers import LOG
 from tktl.core.managers.base import BaseConfigManager
 from tktl.core.managers.constants import TEMPLATE_PROJECT_DIRS, TEMPLATE_PROJECT_FILES
 from tktl.core.validation.project import validate_project_contents
 
-logger = CliLogger()
-
 
 class ProjectManager(BaseConfigManager):
     """Manages project configuration tktl.yaml file."""
 
-    TKTL_DIR: str = None
+    TKTL_DIR: Optional[str] = None
     CONFIG_FILE_NAME: str = "tktl.yaml"
-    CONFIG: dict = None
+    CONFIG: Optional[dict] = None
 
     @classmethod
     def set_path(cls, path: str) -> None:
@@ -42,7 +41,7 @@ class ProjectManager(BaseConfigManager):
 
     @classmethod
     def safe_init(cls, path: Optional[str], name: str) -> None:
-        logger.log(
+        LOG.log(
             "WARNING: Path specified already exists. "
             "Any configuration will be overwritten. Proceed?[Y/n]",
             color="yellow",
@@ -76,7 +75,7 @@ class ProjectManager(BaseConfigManager):
         file_path = file.replace("template/", replace_path)
         try:
             with open(os.path.join(cls.TKTL_DIR, file_path), "w") as f:
-                f.write(data.decode("utf-8"))
+                f.write(data.decode("utf-8").replace("__version__", __version__))
         except UnicodeDecodeError:
             with open(os.path.join(cls.TKTL_DIR, file_path), "wb") as f:
                 f.write(data)
