@@ -18,7 +18,7 @@ class RequiredUserProjectPathsT(str, ExtendedEnum):
     SRC = "src"
     TKTL_YML = "tktl.yml"
     TKTL_YAML = "tktl.yaml"
-    DOCKERFILE = "Dockerfile"
+    DOCKERFILE = ".buildfile"
     REQS = "requirements.txt"
 
     @classmethod
@@ -59,6 +59,8 @@ class InstanceTypeT(str, ExtendedEnum):
     GP_SMALL = "gp.small"
     GP_MEDIUM = "gp.medium"
     GP_LARGE = "gp.large"
+    GP_XLARGE = "gp.xlarge"
+    GP_2XLARGE = "gp.2xlarge"
 
 
 class ServiceT(str, ExtendedEnum):
