@@ -12,10 +12,7 @@ def validate_outputs(preds) -> Union[bool, Iterator]:
     if not isinstance(preds, pandas.Series):
         try:
             preds = pandas.Series(preds, dtype=float)
-        except Exception as e:
-            LOG.warning(
-                f"Could not cast predictions to series: {e}, profiling won't happen"
-            )
+        except ValueError:
             return False
     if not ptypes.is_numeric_dtype(pandas.Series(preds)):
         LOG.warning("Function return types are not numeric, profiling won't happen")
